@@ -4,11 +4,9 @@
 import time
 
 class Attack(object):
-    '''
-        Contains functionality common to all attacks
-    '''
+    '''Contains functionality common to all attacks.'''
 
-    target_wait = 20
+    target_wait = 60
 
     def __init__(self, target):
         self.target = target
@@ -17,17 +15,13 @@ class Attack(object):
         raise Exception("Unimplemented method: run")
 
     def wait_for_target(self, airodump):
-        '''
-            Waits for target to appear in airodump
-        '''
+        '''Waits for target to appear in airodump.'''
         start_time = time.time()
         targets = airodump.get_targets(apply_filter=False)
         while len(targets) == 0:
             # Wait for target to appear in airodump.
             if int(time.time() - start_time) > Attack.target_wait:
-                raise Exception(
-                    "Target did not appear after %d seconds, stopping"
-                    % Attack.target_wait)
+                raise Exception('Target did not appear after %d seconds, stopping' % Attack.target_wait)
             time.sleep(1)
             targets = airodump.get_targets()
             continue
